The periods for the data.
If the frequency is for years they are the numbers of the years, if it is quarterly the format is N<U+00BA> TRIM. YYYY, N is the quarter and YYYY the year.
If the frequency is monthly the format is MM-YYYY with MM being the month number, always with two digits: 01, 02, ..., 12.
nivel
The level of disaggregation : PROVINCIA or COMUNIDAD AUTONOMA
zonas
A vector with the provinces if nivel is "PROVINCIA" or "CASTILLA y LEON" y/o "ESPA<d1>A" if nivel is "COMUNIDAD AUTONOMA"
frecuencia
The frequency of the data: YEAR (A<d1>O), QUARTER (TRIMESTRE) or MONTH (MES)
Value
A data.frame with the data.
If there is an error return NULLL.
The data.frame with 5 columns.
The columns are:
ZONA: the name of province or comunidad.
SERIE: The name of the variable.
UNIDAD DE MEDIDA: The units of variable.
ANNO or TRIMESTRE or MES : The period of the data.
Valor: The data.
Details
If variables, periodos or zonas are NULL the data obtained are all available without considering the relevant condition.