leerSIECyL
The DESCRIPTION file: leerSIECyL leerSIECyL The SIECyL is the System of Statistical Information (Sistema de Informaci<U+000EE805>stad<ed>stica) of the govern of Castilla y Le<U+000EE828>Spain). Access to the data is possible through the page http://estadistica.jcyl.es, but also using a query API. This package uses this API to access any of the modules, at the moment only Datos B<e1>sicos, Coyuntura and Padr<f3>n. The three main functions are: leerDB to obtain data from the Datos B<e1>sicos module leerCoyuntura to do it from the Coyuntura module. leerPadron to do it from the Padr<U+000EE82D>odule.